@@ -152,28 +152,25 @@ get_annot_color (PopplerAnnot *poppler_annot)
 
     if ((poppler_color = poppler_annot_get_color (poppler_annot))) {
         GdkPixbuf *pixbuf;
+	gint rowstride, num, x;
+	guchar *pixels;
 
         pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB,
                                  FALSE, 8,
                                  64, 16);
 
-        if (pixbuf) {
-            gint rowstride, num, x;
-            guchar *pixels;
-
-            rowstride = gdk_pixbuf_get_rowstride (pixbuf);
-            pixels = gdk_pixbuf_get_pixels (pixbuf);
+	rowstride = gdk_pixbuf_get_rowstride (pixbuf);
+	pixels = gdk_pixbuf_get_pixels (pixbuf);
             
-            num = gdk_pixbuf_get_width (pixbuf) *
+	num = gdk_pixbuf_get_width (pixbuf) *
                 gdk_pixbuf_get_height (pixbuf);
 
-            for (x = 0; x < num; x++) {
-                pixels[0] = poppler_color->red * 255;
-                pixels[1] = poppler_color->green * 255;
-                pixels[2] = poppler_color->blue * 255;
-                pixels += 3;
-            }
-        }
+	for (x = 0; x < num; x++) {
+          pixels[0] = poppler_color->red;
+	  pixels[1] = poppler_color->green;
+	  pixels[2] = poppler_color->blue;
+	  pixels += 3;
+	}
 
         g_free (poppler_color);
 
@@ -187,64 +184,18 @@ gchar *
 get_markup_date (PopplerAnnotMarkup *poppler_annot)
 {
     GDate *date;
+    struct tm t;
+    time_t timet;
 
-    if ((date = poppler_annot_markup_get_date (poppler_annot))) {
-        gchar *text;
-        
-        text = g_strdup_printf ("D: %d:", g_date_get_day (date));
-        
-        switch (g_date_get_month (date))
-        {
-          case G_DATE_BAD_MONTH:
-            text = g_strdup_printf ("%s,M: Bad", text);
-            break;
-          case G_DATE_JANUARY:
-            text = g_strdup_printf ("%s,M: January", text);
-            break;
-          case G_DATE_FEBRUARY:
-            text = g_strdup_printf ("%s,M: February", text);
-            break;
-          case G_DATE_MARCH:
-            text = g_strdup_printf ("%s,M: March", text);
-            break;
-          case G_DATE_APRIL:
-            text = g_strdup_printf ("%s,M: April", text);
-            break;
-          case G_DATE_MAY:
-            text = g_strdup_printf ("%s,M: May", text);
-            break;
-          case G_DATE_JUNE:
-            text = g_strdup_printf ("%s,M: June", text);
-            break;
-          case G_DATE_JULY:
-            text = g_strdup_printf ("%s,M: July", text);
-            break;
-          case G_DATE_AUGUST:
-            text = g_strdup_printf ("%s,M: August", text);
-            break;
-          case G_DATE_SEPTEMBER:
-            text = g_strdup_printf ("%s,M: September", text);
-            break;
-          case G_DATE_OCTOBER:
-            text = g_strdup_printf ("%s,M: October", text);
-            break;
-          case G_DATE_NOVEMBER:
-            text = g_strdup_printf ("%s,M: November", text);
-            break;
-          case G_DATE_DECEMBER:
-            text = g_strdup_printf ("%s,M: December", text);
-            break;
-          default:
-            text = g_strdup_printf ("%s,M: Unknown", text);
-            break;
-        }
-        text = g_strdup_printf ("%s,Y: %d", text, g_date_get_year (date));
+    date = poppler_annot_markup_get_date (poppler_annot);
+    if (!date)
+	    return NULL;
 
-        g_free (date);
-        return text;
-    }
+    g_date_to_struct_tm (date, &t);
+    g_date_free (date);
 
-    return NULL;
+    timet = mktime (&t);
+    return timet == (time_t) - 1 ? NULL : pgd_format_date (timet);
 }
 
 const gchar *
@@ -352,13 +303,22 @@ pgd_annot_view_set_annot_markup (GtkWidget          *table,
                                  gint               *row)
 {
     gchar *text;
+    PopplerRectangle rect;
 
     text = poppler_annot_markup_get_label (markup);
     pgd_table_add_property (GTK_TABLE (table), "<b>Label:</b>", text, row);
     g_free (text);
 
-    pgd_table_add_property (GTK_TABLE (table), "<b>Popup is open:</b>",
-                            poppler_annot_markup_get_popup_is_open (markup) ? "Yes" : "No", row);
+    if (poppler_annot_markup_has_popup (markup)) {
+	    pgd_table_add_property (GTK_TABLE (table), "<b>Popup is open:</b>",
+				    poppler_annot_markup_get_popup_is_open (markup) ? "Yes" : "No", row);
+
+	    poppler_annot_markup_get_popup_rectangle (markup, &rect);
+	    text = g_strdup_printf ("X1: %.2f, Y1: %.2f, X2: %.2f, Y2: %.2f",
+				    rect.x1, rect.y1, rect.x2, rect.y2);
+	    pgd_table_add_property (GTK_TABLE (table), "<b>Popup Rectangle:</b>", text, row);
+	    g_free (text);
+    }
 
     text = g_strdup_printf ("%f", poppler_annot_markup_get_opacity (markup));
     pgd_table_add_property (GTK_TABLE (table), "<b>Opacity:</b>", text, row);
@@ -417,6 +377,7 @@ pgd_annot_view_set_annot (GtkWidget    *annot_view,
     GEnumValue *enum_value;
     gint        row = 0;
     gchar      *text, *warning;
+    time_t      timet;
 
     alignment = gtk_bin_get_child (GTK_BIN (annot_view));
     if (alignment) {
@@ -444,6 +405,10 @@ pgd_annot_view_set_annot (GtkWidget    *annot_view,
     g_free (text);
 
     text = poppler_annot_get_modified (annot);
+    if (poppler_date_parse (text, &timet)) {
+	    g_free (text);
+	    text = pgd_format_date (timet);
+    }
     pgd_table_add_property (GTK_TABLE (table), "<b>Modified:</b>", text, &row);
     g_free (text);
 
